# Feedback

Display a brief text message indicating whether the **previous** response was correct or incorrect, with configurable messages and colors.

## When To Use

- Trial-by-trial correctness feedback.
- Simple score/progress indication using text and color.
- Immediate reinforcement after a keypress response.